@@ -134,8 +134,7 @@ fairness_check <- function(x,
                         green_start = "", green_end = "")
   }
 
-  verbose_cat("Creating fairness object\n", verbose = verbose)
-  verbose_cat("-> Privileged subgroup\t\t: ", verbose = verbose)
+  verbose_cat("Creating fairness classification object\n", verbose = verbose)
 
   ################  data extraction  ###############
 
@@ -159,49 +158,18 @@ fairness_check <- function(x,
 
   ### protected & privileged
 
-  if (is.null(privileged)) {
-    if (length(fobjects) > 0) {
-      # getting from first explainer - checking is later
-      privileged <- fobjects[[1]][["privileged"]]
-      verbose_cat(class(privileged), "(" , verbose = verbose)
-      verbose_cat(color_codes$yellow_start, "from first fairness object", color_codes$yellow_end, ") \n", verbose = verbose)
-    } else {
-      stop ("\nPrivileged cannot be NULL if fairness_objects are not provided")
-    }} else {
-        # if protected and privileged are not characters, changing them
-        if (is.character(privileged) | is.factor(privileged)) {
-          verbose_cat(class(privileged), "(", verbose = verbose)
-          verbose_cat(color_codes$green_start, "Ok", color_codes$green_end, ")\n", verbose = verbose)
-        } else {
-          verbose_cat("character (", verbose = verbose)
-          verbose_cat(color_codes$yellow_start, "changed from", class(privileged), color_codes$yellow_end, ")\n", verbose = verbose)
-        }
-      }
+  verbose_cat("-> Privileged subgroup\t\t: ", verbose = verbose)
+  privileged <- check_privileged(privileged, fobjects, verbose = verbose)
 
   verbose_cat("-> Protected variable\t\t:", "factor", "(", verbose = verbose)
-
-
-  if (is.null(protected)) {
-    if (length(fobjects) > 0) {
-      # getting from first explainer - checking is later
-      protected <- fobjects[[1]][["protected"]]
-      verbose_cat(color_codes$yellow_start, "from first fairness object", color_codes$yellow_end, ") \n", verbose = verbose)
-    } else {
-        stop("\nProtected cannot be NULL if fairness_objects are not provided")
-    }} else {
-        if (is.factor(protected)) {
-          verbose_cat(color_codes$green_start, "Ok", color_codes$green_end, ") \n", verbose = verbose)
-        } else {
-          verbose_cat(color_codes$yellow_start, "changed from", class(protected),  color_codes$yellow_end, ")\n", verbose = verbose)
-          protected <- as.factor(protected)
-        }}
+  protected <- check_protected(protected, fobjects, verbose = verbose)
 
   protected_levels <- levels(protected)
   n_lvl            <- length(protected_levels)
 
   if (! privileged %in% protected_levels) stop("privileged subgroup is not in protected variable vector")
 
-  #### cutoff handling- if cutoff is null than 0.5 for all subgroups
+  ############### cutoff handling- if cutoff is null than 0.5 for all subgroups ###############
 
   verbose_cat("-> Cutoff values for explainers\t: ", verbose = verbose)
 
@@ -241,81 +209,23 @@ fairness_check <- function(x,
   }
 
 
-  ### epsilon
+  ############### epsilon ###############
   if (is.null(epsilon)) epsilon <- 0.8
   if (! check_if_numeric_and_single(epsilon)) stop("Epsilon must be single, numeric value")
   if (! check_values(epsilon, 0, 1) )       stop ("epsilon must be within 0 and 1")
 
-  ### fairness objects
-  # among all fairness_objects parameters should be equal
+  ############### explainers & fairness objects ###############
 
   verbose_cat("-> Fairness objects\t\t:", length(fobjects), verbose = verbose)
-  if (length(fobjects) == 1){
-    verbose_cat(" object ", verbose = verbose)
-      } else {
-    verbose_cat(" objects ", verbose = verbose)
-  }
+  fobjects <- check_fobjects(fobjects, protected, privileged, verbose = verbose)
 
-
-  if (length(fobjects) > 0) {
-    if(! all(sapply(fobjects, function(x) x$protected == protected))) {
-       verbose_cat("(",color_codes$red_start, "not compatible" ,color_codes$red_end, ") \n", verbose = verbose)
-       stop("fairness objects must have the same protected vector as one passed in fairness check")
-    }
-    if(! all(sapply(fobjects, function(x) x$privileged == privileged))) {
-      verbose_cat("(", color_codes$red_start, "not compatible" ,color_codes$red_end, ") \n", verbose = verbose)
-      stop("fairness objects must have the same privlieged argument as one passed in fairness check")
-    }
-  verbose_cat("(", color_codes$green_start, "compatible", color_codes$yellow_end,  ")\n", verbose = verbose)
-  } else {
-    verbose_cat("\n", verbose = verbose)}
-
-  ### explainers
-  # must have equal y
   verbose_cat("-> Checking explainers\t\t:", length(all_explainers), "in total ", verbose = verbose)
-
-  # if there are explainers
-  if (length(all_explainers) > 0) {
-    y_to_compare <- all_explainers[[1]]$y
-
-    if(! all(sapply(all_explainers, function(x) length(y_to_compare) == length(x$y)))) {
-      verbose_cat(color_codes$red_start, "y not equal", color_codes$red_end, "\n", verbose = verbose)
-      stop("All explainer predictions (y) must have same length")
-  }
-
-  if(! all(sapply(all_explainers, function(x) y_to_compare == x$y))) {
-    verbose_cat(color_codes$red_start, "y not equal", color_codes$red_end, "\n", verbose = verbose)
-    stop("All explainers must have same values of target variable")
-  }
-
-  if(! all(sapply(all_explainers, function(x) length(x$y) == length(protected)))) {
-    verbose_cat(color_codes$red_start, "not compatible", color_codes$red_end, "\n", verbose = verbose)
-    stop("Lengths of protected variable and target variable in explainer differ")
-  } } else {
-      verbose_cat(color_codes$red_start, "no explainers", color_codes$red_end, "\n", verbose = verbose)
-      stop("At least one explainer must be provided")
-  }
-
-  verbose_cat("(", color_codes$green_start, "compatible", color_codes$yellow_end,  ")\n", verbose = verbose)
-
-  if (is.null(label)) {
-    label     <- sapply(explainers, function(x) x$label)
-  } else {
-    if (length(label) != n_exp) stop("Number of labels must be equal to number of explainers (outside fairness objects)")
-  }
-
-  # explainers must have unique labels
-  if (length(unique(label)) != length(label) ) {
-   stop("Explainers don't have unique labels
-        ( pass paramter \'label\' to fairness_check() or before to explain() function)")
-  }
-
-  # labels must be unique for all explainers, those in fairness objects too
-  if (any(label %in% fobjects_label)) {
-   stop("Explainer has the same label as label in fairness_object")
-  }
+  all_explainers <- check_explainers_clf(all_explainers, protected, verbose = verbose)
 
 
+  ############### labels ###############
+
+  label <- check_labels(label, explainers, fobjects_label)
 
   ###############  fairness metric calculation  ###############
 
@@ -478,12 +388,3 @@ fairness_check <- function(x,
   return(fairness_object)
 }
 
-color_codes <- list(yellow_start = "\033[33m", yellow_end = "\033[39m",
-                    red_start = "\033[31m", red_end = "\033[39m",
-                    green_start = "\033[32m", green_end = "\033[39m")
-
-verbose_cat <- function(..., verbose = TRUE) {
-  if (verbose) {
-    cat(...)
-  }
-}
